@@ -2,16 +2,12 @@
 source $MINER_DIR/$CUSTOM_MINER/h-manifest.conf
 
 algo='aleo'
-version="3.0.3"
+version="3.0.6"
 stats=""
 unit="S/s"
 khs=0
-hs=()
-temp=()
-fan=()
-numbers=()
 
-khs=$(cat /root/hive/miners/custom/aleominer/aleominer1.log |grep "Speed(S/s)" | awk 'END {print}'| awk '{print $3}')
+khs=$(tail -n 100 /var/log/miner/custom/aleominer1.log |grep "Speed(S/s)" | awk 'END {print}'| awk '{print $3}')
 khs=$(echo "scale=5; $khs / 1000" | bc)
 
 khs_num=$(echo "$khs" | jq -R . | jq -s 'map(tonumber)[0]')
